@@ -1,6 +1,5 @@
 package urpm::download;
 
-# $Id: download.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use urpm::msg;
@@ -278,7 +277,7 @@ sub set_proxy {
 	if (my ($http_proxy) = $p->{http_proxy} && parse_http_proxy($p->{http_proxy})) {
 	    my $allproxy = $p->{user}; 
 	    $allproxy .= ":" . $p->{pwd} if $p->{pwd}; 
-	    $allproxy .= "@";
+	    $allproxy .= "@" if $p->{user};
 	    $allproxy .= $http_proxy;
 	    @res = ("--all-proxy=http://$allproxy");
 	}
@@ -816,11 +815,13 @@ END {
 
 #- get the width of the terminal
 my $wchar = 79;
-eval {
+if (-t STDOUT) {
+  eval {
     require Term::ReadKey;
     ($wchar) = Term::ReadKey::GetTerminalSize();
     --$wchar;
-};
+  };
+}
 
 sub progress_text {
     my ($mode, $percent, $total, $eta, $speed) = @_;
