@@ -37,7 +37,7 @@ sub parse {
 }
 
 
-=item check_file($md5sum_file)
+=item parse($md5sum_file)
 
 Check size and parse a MD5SUM file.
 Returns a hash of file => md5sum 
@@ -100,6 +100,7 @@ sub compute {
 
 1;
 
+__END__
 
 =back
 
@@ -109,6 +110,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
