@@ -275,14 +275,8 @@ sub add_proximity_and_sort {
 	$_->{proximity_corrected} = $_->{proximity} * _random_correction();
 	$_->{proximity_corrected} *= _between_country_correction($country_code, $_->{country}) if $best;
 	$_->{proximity_corrected} *= _between_continent_correction($best->{continent}, $_->{continent}) if $best;
-	$_->{proximity_corrected} *= _protocol_correction($_->{url});
     }
-
     @$mirrors = sort { $a->{proximity_corrected} <=> $b->{proximity_corrected} } @$mirrors;
-
-    #foreach (@$mirrors) {
-    #	    print $_->{proximity_corrected} . " " . $_->{proximity}  . " " . $_->{url} . "\n";
-    #}
 }
 
 # add +/- 5% random
@@ -296,7 +290,6 @@ sub _between_country_correction {
     $here && $mirror or return 1;
     $here eq $mirror ? 0.5 : 1;
 }
-
 sub _between_continent_correction {
     my ($here, $mirror) = @_;
     $here && $mirror or return 1;
@@ -305,15 +298,6 @@ sub _between_continent_correction {
 	1;
 }
 
-sub _protocol_correction {
-    my ($url) = @_;
-    # favor encrypted protocols, then http
-    ( $url =~ m!https://! ) and return 0.7;
-    ( $url =~ m!ftps://! ) and return 0.8;
-    ( $url =~ m!http://! ) and return 0.9;
-    1;
-}
-
 sub _mirrors_raw {
     my ($urpm, $url) = @_;
 
@@ -338,15 +322,15 @@ sub _mageia_mirrorlist {
     my ($product_id, $o_arch) = @_;
 
     #- contact the following URL to retrieve the list of mirrors.
-    #- https://wiki.mageia.org/en/Product_id
+    #- http://wiki.mandriva.com/en/Product_id
     my $_product_type = lc($product_id->{type}); $product_id =~ s/\s//g;
     my $arch = $o_arch || $product_id->{arch};
 
     my @para = grep { $_ } $ENV{URPMI_ADDMEDIA_REASON};
     my $product_version = $ENV{URPMI_ADDMEDIA_PRODUCT_VERSION} || $product_id->{version};
 
-    #"https://mirrors.mageia.org/api/$product_type.$product_version.$arch.list"
-    "https://mirrors.mageia.org/api/mageia.$product_version.$arch.list"
+    #"http://mirrors.mageia.org/api/$product_type.$product_version.$arch.list"
+    "http://mirrors.mageia.org/api/mageia.$product_version.$arch.list"
       . (@para ? '?' . join('&', @para) : '');
 }
 
@@ -367,6 +351,7 @@ sub parse_LDAP_namespace_structure {
 
 1;
 
+__END__
 
 =back
 
@@ -376,6 +361,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
