@@ -5,7 +5,6 @@ use urpm::util qw(add2hash_ append_to_file cat_ output_safe partition put_in_has
 use urpm::msg;
 use urpm;
 
-# $Id: select.pm 243120 2008-07-01 12:24:34Z pixel $
 
 my $fullname2name_re = qr/^(.*)-[^\-]*-[^\-]*\.[^\.\-]*$/;
 
@@ -49,6 +48,12 @@ sub unrequested_list__file {
     ($urpm->{env_dir} || "$urpm->{root}/var/lib/rpm") . '/installed-through-deps.list';
 }
 
+=item unrequested_list($urpm)
+
+Returns the list of potentiel files (ake files installed as requires for others)
+
+=cut
+
 #- side-effects: none
 sub unrequested_list {
     my ($urpm) = @_;
@@ -89,6 +94,20 @@ sub mark_as_requested {
     }
 }
 
+=item _installed_req_and_unreq($urpm)
+
+Returns :
+
+=over
+
+=item * req: list of installed packages that were installed as requires of others 
+
+=item * unreq: list of installed packages that were not installed as requres of others (ie the ones that were explicitely selected for install)
+
+=back
+
+=cut
+
 #- side-effects:
 #-   + those of _installed_req_and_unreq_and_update_unrequested_list (<root>/var/lib/rpm/installed-through-deps.list)
 sub _installed_req_and_unreq {
@@ -97,6 +116,20 @@ sub _installed_req_and_unreq {
     ($req, $unreq);
 }
 
+=item _installed_and_unrequested_lists($urpm)
+
+Returns :
+
+=over
+
+=item * pkgs: list of installed packages
+
+=item * unrequested: list of packages that were installed as requires of others (the sum of the previous lists)
+
+=back
+
+=cut
+
 #- side-effects:
 #-   + those of _installed_req_and_unreq_and_update_unrequested_list (<root>/var/lib/rpm/installed-through-deps.list)
 sub _installed_and_unrequested_lists {
@@ -118,6 +151,22 @@ sub _write_unrequested_list__file {
 		".old") if !$urpm->{env_dir};
 }
 
+=item _installed_req_and_unreq_and_update_unrequested_list ($urpm)
+
+Returns :
+
+=over
+
+=item * req: list of installed packages that were installed as requires of others 
+
+=item * unreq: list of installed packages that were not installed as requres of others (ie the ones that were explicitely selected for install)
+
+=item * unrequested: list of packages that were installed as requires of others (the sum of the previous lists)
+
+=back
+
+=cut
+
 #- side-effects: those of _write_unrequested_list__file
 sub _installed_req_and_unreq_and_update_unrequested_list {
     my ($urpm) = @_;
@@ -138,9 +187,13 @@ sub _installed_req_and_unreq_and_update_unrequested_list {
     ($req, $unreq, $unrequested);
 }
 
-#- returns the new "unrequested" packages
-#- the reason can be "required by xxx" or "recommended"
-#-
+=item _selected_unrequested($urpm, $selected, $rejected)
+
+Returns the new "unrequested" packages.
+The reason can be "required by xxx" or "recommended"
+
+=cut
+
 #- side-effects: none
 sub _selected_unrequested {
     my ($urpm, $selected, $rejected) = @_;
@@ -160,8 +213,12 @@ sub _selected_unrequested {
     } keys %$selected;
 }
 
-#- returns the packages obsoleting packages marked "unrequested"
-#- 
+=item _renamed_unrequested($urpm, $selected, $rejected)
+
+Returns the packages obsoleting packages marked "unrequested"
+
+=cut
+
 #- side-effects: none
 sub _renamed_unrequested {
     my ($urpm, $selected, $rejected) = @_;
@@ -279,11 +336,15 @@ sub _unrequested_orphans_after_remove_once {
     0;
 }
 
-#- return true if $pkg will no more be required after removing $toremove
-#-
-#- nb: it may wrongly return false for complex loops,
-#-     but will never wrongly return true
-#-
+=item _will_package_be_unneeded($urpm, $db, $toremove, $pkg)
+
+Return true if $pkg will no more be required after removing $toremove
+
+nb: it may wrongly return false for complex loops,
+but will never wrongly return true
+
+=cut
+
 #- side-effects: none
 sub _will_package_be_unneeded {
     my ($urpm, $db, $toremove, $pkg) = @_;
@@ -314,8 +375,12 @@ sub _will_package_be_unneeded {
     1;
 }
 
-#- return true if $prop will still be required after removing $toremove
-#-
+=item _will_prop_still_be_needed($urpm, $db, $toremove, $fullname, $prop, $required_maybe_loop)
+
+Return true if $prop will still be required after removing $toremove
+
+=cut
+
 #- side-effects: none
 sub _will_prop_still_be_needed {
     my ($urpm, $db, $toremove, $fullname, $prop, $required_maybe_loop) = @_;
@@ -343,7 +408,13 @@ sub _will_prop_still_be_needed {
     });
 }
 
-# so that we can filter out current running kernel:
+=item _get_current_kernel_package()
+
+Return the current kernel's package so that we can filter out current running
+kernel:
+
+=cut
+
 sub _get_current_kernel_package() {
     my $release = (POSIX::uname())[2];
     # --qf '%{name}' is used in order to provide the right format:
@@ -351,18 +422,22 @@ sub _get_current_kernel_package() {
 }
 
 
-# - returns list of kernels
-#
-# _fast_ version w/o looking at all non kernel packages requires on
-# kernels (like "urpmi_find_leaves '^kernel'" would)
-#
-# _all_unrequested_orphans blacklists nearly all kernels b/c of packages
-# like 'ndiswrapper' or 'basesystem' that requires 'kernel'
-#
-# rationale: other packages only require 'kernel' or a sub package we
-# do not care about (eg: kernel-devel, kernel-firmware, kernel-latest)
-# so it's useless to look at them
-#
+=item _kernel_callback ($pkg, $unreq_list)
+
+Returns list of kernels
+
+_fast_ version w/o looking at all non kernel packages requires on
+kernels (like "urpmi_find_leaves '^kernel'" would)
+
+_all_unrequested_orphans blacklists nearly all kernels b/c of packages
+like 'ndiswrapper' or 'basesystem' that requires 'kernel'
+
+rationale: other packages only require 'kernel' or a sub package we
+do not care about (eg: kernel-devel, kernel-firmware, kernel-latest)
+so it's useless to look at them
+
+=cut
+
 my (@req_by_latest_kernels, %requested_kernels, %kernels);
 sub _kernel_callback { 
     my ($pkg, $unreq_list) = @_;
@@ -393,7 +468,12 @@ sub _kernel_callback {
 }
 
 
-# - returns list of orphan kernels
+=item _get_orphan_kernels()
+
+Returns list of orphan kernels
+
+=cut
+
 sub _get_orphan_kernels() {
     # keep kernels required by kernel-*-latest:
     delete $kernels{$_} foreach @req_by_latest_kernels;
@@ -402,13 +482,18 @@ sub _get_orphan_kernels() {
 }
 
 
-#- returns the list of "unrequested" orphans.
-#-
+=item _all_unrequested_orphans($urpm, $req, $unreq)
+
+Returns the list of "unrequested" orphans.
+
+=cut
+
 #- side-effects: none
 sub _all_unrequested_orphans {
     my ($urpm, $req, $unreq) = @_;
 
     my (%l, %provides);
+    # 1- list explicit provides (not files) from installed packages:
     foreach my $pkg (@$unreq) {
 	$l{$pkg->name} = $pkg;
 	push @{$provides{$_}}, $pkg foreach $pkg->provides_nosense;
@@ -417,6 +502,7 @@ sub _all_unrequested_orphans {
 
     my ($current_kernel_version, $current_kernel) = _get_current_kernel_package();
 
+    # 2- check if "unrequested" packages are still needed:
     while (my $pkg = shift @$req) {
         # do not do anything regarding kernels if we failed to detect the running one (ie: chroot)
  	_kernel_callback($pkg, $unreq_list) if $current_kernel;
