@@ -28,8 +28,8 @@ our @EXPORT = qw(add2hash_
     put_in_hash
     quotespace
     reduce_pathname
+    remove_internal_name
     same_size_and_mtime
-    uefi_type
     uniq
     uniq_
     unquotespace
@@ -37,38 +37,13 @@ our @EXPORT = qw(add2hash_
     wc_l
 );
 
-
-=head1 NAME
-
-urpm::util - Misc. utilities subs for urpmi
-
-Mostly a subset of L<MDK::Common>
-
-See C<perldoc MDK::Common> for more documentation
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-=over
-
-=cut
-
 sub min  { my $n = shift; $_ < $n and $n = $_ foreach @_; $n }
 sub max  { my $n = shift; $_ > $n and $n = $_ foreach @_; $n }
 
-=item quotespace($str)
-
-=item unquotespace($str)
-
-Quoting/unquoting a string that may be containing space chars.
-
-=cut
-
+#- quoting/unquoting a string that may be containing space chars.
 sub quotespace		 { my $x = $_[0] || ''; $x =~ s/(\s)/\\$1/g; $x }
 sub unquotespace	 { my $x = $_[0] || ''; $x =~ s/\\(\s)/$1/g; $x }
+sub remove_internal_name { my $x = $_[0] || ''; $x =~ s/\(\S+\)$/$1/g; $x }
 
 sub dirname { local $_ = shift; s|[^/]*/*\s*$||; s|(.)/*$|$1|; $_ || '.' }
 sub basename { local $_ = shift; s|/*\s*$||; s|.*/||; $_ }
@@ -83,19 +58,14 @@ sub file2absolute_file {
     $f;
 }
 
-=item reduce_pathname($url)
-
-Reduce pathname by removing <something>/.. each time it appears (or . too).
-
-=cut
-
+#- reduce pathname by removing <something>/.. each time it appears (or . too).
 sub reduce_pathname {
     my ($url) = @_;
 
     #- clean url to remove any macro (which cannot be solved now).
     #- take care if this is a true url and not a simple pathname.
     my ($host, $dir) = $url =~ m|([^:/]*://[^/]*/)?(.*)|;
-    $host //= '';
+    $host = '' if !defined $host;
 
     #- remove any multiple /s or trailing /.
     #- then split all components of pathname.
@@ -123,13 +93,8 @@ sub reduce_pathname {
     $host . $dir;
 }
 
-=item offset_pathname($url, $offset)
-
-Offset pathname by returning the right things to add to a relative directory
-to make no change. url is needed to resolve going before to top base.
-
-=cut
-
+#- offset pathname by returning the right things to add to a relative directory
+#- to make no change. url is needed to resolve going before to top base.
 sub offset_pathname {
     my ($url, $offset) = map { reduce_pathname($_) } @_;
 
@@ -170,12 +135,7 @@ sub move {
     rename($file, $dest) || !system("/bin/mv", "-f", $file, $dest);
 }
 
-=item file_size($file)
-
-It is useful to write file_size(...) > 32 without having warnings if file doesn't exist
-
-=cut
-
+#- file_size is useful to write file_size(...) > 32 without having warnings if file doesn't exist
 sub file_size {
     my ($file) = @_;
     -s $file || 0;
@@ -226,20 +186,7 @@ sub uniq_(&@) {
 
 sub output_safe {
     my ($file, $content, $o_backup_ext) = @_;
-
-    #- The file must be world-readable, else mgaapplet and urpm* commands run as
-    #- a normal user won't be able to read it. We enforce umask here in the case
-    #- where the msec security level is set to 'secure' (which means umask 077)
-    #- or where we are run from a gdm-x-session (mga#24636)
-    my $old_umask = umask 0022;
-    my $retval = output_safe_($file, $content, $o_backup_ext);
-    umask $old_umask;
-    $retval;
-}
-
-sub output_safe_ {
-    my ($file, $content, $o_backup_ext) = @_;
-
+    
     open(my $f, '>', "$file.new") or return;
     print $f $content or return;
     close $f or return;
@@ -268,25 +215,19 @@ sub append_to_file {
     1;
 }
 
-=item uefi_type()
-
-Return the UEFI machine type short name
-
-=cut
-
-# FIXME: move into urpm::sys ?
-sub uefi_type() {
-    if (-e '/sys/firmware/efi/fw_platform_size') {
-        # No support for ARM yet
-        cat_('/sys/firmware/efi/fw_platform_size') =~ /32/ ? 'ia32' : 'x64';
-    } else {
-        'none';
-    }
-}
-
 1;
 
-=back
+__END__
+
+=head1 NAME
+
+urpm::util - Misc. utilities subs for urpmi
+
+Mostly a subset of L<MDK::Common>
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
 
 =head1 COPYRIGHT
 
@@ -294,6 +235,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
